==> monaco-vscode-view-common-service-override-4.5.1.tgz: package/viewCommon.js <==
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { IViewDescriptorService } from 'vscode/vscode/vs/workbench/common/views.service';
import { ViewDescriptorService } from './vscode/src/vs/workbench/services/views/browser/viewDescriptorService.js';
import { IActivityService } from 'vscode/vscode/vs/workbench/services/activity/common/activity.service';
import { ActivityService } from './vscode/src/vs/workbench/services/activity/browser/activityService.js';
import { IPaneCompositePartService } from 'vscode/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';
import { IEditorResolverService } from 'vscode/vscode/vs/workbench/services/editor/common/editorResolverService.service';
import { EditorResolverService } from './vscode/src/vs/workbench/services/editor/browser/editorResolverService.js';
import { BreadcrumbsService } from 'vscode/vscode/vs/workbench/browser/parts/editor/breadcrumbs';
import { IBreadcrumbsService } from 'vscode/vscode/vs/workbench/browser/parts/editor/breadcrumbs.service';
import { IContextViewService } from 'vscode/vscode/vs/platform/contextview/browser/contextView.service';
import { ContextViewService } from 'vscode/vscode/vs/platform/contextview/browser/contextViewService';
import { ICodeEditorService } from 'vscode/vscode/vs/editor/browser/services/codeEditorService';
import { TextEditorService } from 'vscode/vscode/vs/workbench/services/textfile/common/textEditorService';
import { ITextEditorService } from 'vscode/vscode/vs/workbench/services/textfile/common/textEditorService.service';
import { CodeEditorService } from 'vscode/vscode/vs/workbench/services/editor/browser/codeEditorService';
import { UntitledTextEditorService } from './vscode/src/vs/workbench/services/untitled/common/untitledTextEditorService.js';
import { IUntitledTextEditorService } from 'vscode/vscode/vs/workbench/services/untitled/common/untitledTextEditorService.service';
import { IHistoryService } from 'vscode/vscode/vs/workbench/services/history/common/history.service';
import { HistoryService } from './vscode/src/vs/workbench/services/history/browser/historyService.js';
import { ICustomEditorService } from 'vscode/vscode/vs/workbench/contrib/customEditor/common/customEditor.service';
import { CustomEditorService } from './vscode/src/vs/workbench/contrib/customEditor/browser/customEditors.js';
import { WebviewService } from './vscode/src/vs/workbench/contrib/webview/browser/webviewService.js';
import { WebviewEditorService } from 'vscode/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService';
import { IWebviewWorkbenchService } from 'vscode/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService.service';
import { IWebviewService } from 'vscode/vscode/vs/workbench/contrib/webview/browser/webview.service';
import { WebviewViewService } from './vscode/src/vs/workbench/contrib/webviewView/browser/webviewViewService.js';
import { IWebviewViewService } from 'vscode/vscode/vs/workbench/contrib/webviewView/browser/webviewViewService.service';
import { IProgressService } from 'vscode/vscode/vs/platform/progress/common/progress.service';
import { ProgressService } from './vscode/src/vs/workbench/services/progress/browser/progressService.js';
import { PaneCompositePartService } from './vscode/src/vs/workbench/browser/parts/paneCompositePartService.js';
import { BrowserAuxiliaryWindowService } from './vscode/src/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService.js';
import { IAuxiliaryWindowService } from 'vscode/vscode/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService.service';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';
import { ViewsService } from 'vscode/vscode/vs/workbench/services/views/browser/viewsService';
import { IHoverService } from 'vscode/vscode/vs/platform/hover/browser/hover.service';
import { IEditorPaneService } from 'vscode/vscode/vs/workbench/services/editor/common/editorPaneService.service';
import { EditorPaneService } from './vscode/src/vs/workbench/services/editor/browser/editorPaneService.js';
import { HoverService } from 'vscode/vscode/vs/editor/browser/services/hoverService/hoverService';
import { CustomEditorLabelService } from 'vscode/vscode/vs/workbench/services/editor/common/customEditorLabelService';
import { ICustomEditorLabelService } from 'vscode/vscode/vs/workbench/services/editor/common/customEditorLabelService.service';
import getServiceOverride$1 from '@codingame/monaco-vscode-bulk-edit-service-override';
import { changeUrlDomain } from './tools/url.js';
import { registerAssets } from 'vscode/assets';
import './vscode/src/vs/workbench/contrib/callHierarchy/browser/callHierarchy.contribution.js';
import './vscode/src/vs/workbench/contrib/typeHierarchy/browser/typeHierarchy.contribution.js';
import './vscode/src/vs/workbench/browser/actions/listCommands.js';
import 'vscode/vscode/vs/workbench/browser/parts/views/media/views.css';
import './vscode/src/vs/workbench/api/browser/viewsExtensionPoint.js';
import './vscode/src/vs/workbench/browser/parts/editor/editor.contribution.js';
import 'vscode/vscode/vs/workbench/browser/workbench.contribution';
import './vscode/src/vs/workbench/contrib/customEditor/browser/customEditor.contribution.js';
import './vscode/src/vs/workbench/contrib/webviewPanel/browser/webviewPanel.contribution.js';
import './vscode/src/vs/workbench/contrib/externalUriOpener/common/externalUriOpener.contribution.js';
import './vscode/src/vs/workbench/contrib/languageStatus/browser/languageStatus.contribution.js';
import './vscode/src/vs/workbench/contrib/mergeEditor/browser/mergeEditor.contribution.js';
import 'vscode/vscode/vs/workbench/contrib/webview/browser/webview.contribution';
import './vscode/src/vs/workbench/contrib/limitIndicator/browser/limitIndicator.contribution.js';
import './vscode/src/vs/workbench/contrib/sash/browser/sash.contribution.js';
import './vscode/src/vs/workbench/contrib/preferences/browser/keyboardLayoutPicker.js';
import 'vscode/vscode/vs/workbench/browser/parts/editor/editor.autosave.contribution';
import 'vscode/vscode/vs/workbench/contrib/files/browser/files.editorPane.contribution';
import 'vscode/vscode/vs/workbench/contrib/files/browser/fileCommands.save';
import './vscode/src/vs/workbench/browser/actions/navigationActions.js';
import './vscode/src/vs/workbench/browser/style.js';
import './tools/editorAssets.js';
import './vscode/src/vs/workbench/browser/parts/editor/editorParts.js';

let webviewIframeAlternateDomains;
registerAssets({
    'vs/workbench/contrib/webview/browser/pre/service-worker.js': () => changeUrlDomain(new URL('./assets/service-worker.js', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index.html': () => changeUrlDomain(new URL('./assets/index.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index-no-csp.html': () => changeUrlDomain(new URL('./assets/index-no-csp.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/fake.html': () => changeUrlDomain(new URL('./assets/fake.html', import.meta.url).href, webviewIframeAlternateDomains)
});
function getServiceOverride(_webviewIframeAlternateDomains) {
    if (_webviewIframeAlternateDomains != null) {
        webviewIframeAlternateDomains = _webviewIframeAlternateDomains;
    }
    return {
        ...getServiceOverride$1(),
        [( IViewsService.toString())]: new SyncDescriptor(ViewsService, [], false),
        [( IViewDescriptorService.toString())]: new SyncDescriptor(ViewDescriptorService, [], true),
        [( IActivityService.toString())]: new SyncDescriptor(ActivityService, [], true),
        [( IPaneCompositePartService.toString())]: new SyncDescriptor(PaneCompositePartService, [], true),
        [( IHoverService.toString())]: new SyncDescriptor(HoverService, [], true),
        [( ICodeEditorService.toString())]: new SyncDescriptor(CodeEditorService, [], true),
        [( ITextEditorService.toString())]: new SyncDescriptor(TextEditorService, [], false),
        [( IEditorResolverService.toString())]: new SyncDescriptor(EditorResolverService, [], false),
        [( IBreadcrumbsService.toString())]: new SyncDescriptor(BreadcrumbsService, [], true),
        [( IContextViewService.toString())]: new SyncDescriptor(ContextViewService, [], true),
        [( IUntitledTextEditorService.toString())]: new SyncDescriptor(UntitledTextEditorService, [], true),
        [( IHistoryService.toString())]: new SyncDescriptor(HistoryService, [], false),
        [( ICustomEditorService.toString())]: new SyncDescriptor(CustomEditorService, [], true),
        [( IWebviewService.toString())]: new SyncDescriptor(WebviewService, [], true),
        [( IWebviewViewService.toString())]: new SyncDescriptor(WebviewViewService, [], true),
        [( IWebviewWorkbenchService.toString())]: new SyncDescriptor(WebviewEditorService, [], true),
        [( IProgressService.toString())]: new SyncDescriptor(ProgressService, [], true),
        [( IAuxiliaryWindowService.toString())]: new SyncDescriptor(BrowserAuxiliaryWindowService, [], true),
        [( IEditorPaneService.toString())]: new SyncDescriptor(EditorPaneService, [], true),
        [( ICustomEditorLabelService.toString())]: new SyncDescriptor(CustomEditorLabelService, [], true)
    };
}

export { getServiceOverride as default };

==> monaco-vscode-view-common-service-override-5.1.0.tgz: package/viewCommon.js <==
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { IViewDescriptorService } from 'vscode/vscode/vs/workbench/common/views.service';
import { ViewDescriptorService } from './vscode/src/vs/workbench/services/views/browser/viewDescriptorService.js';
import { IActivityService } from 'vscode/vscode/vs/workbench/services/activity/common/activity.service';
import { ActivityService } from './vscode/src/vs/workbench/services/activity/browser/activityService.js';
import { IPaneCompositePartService } from 'vscode/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';
import { IEditorResolverService } from 'vscode/vscode/vs/workbench/services/editor/common/editorResolverService.service';
import { EditorResolverService } from './vscode/src/vs/workbench/services/editor/browser/editorResolverService.js';
import { BreadcrumbsService } from 'vscode/vscode/vs/workbench/browser/parts/editor/breadcrumbs';
import { IBreadcrumbsService } from 'vscode/vscode/vs/workbench/browser/parts/editor/breadcrumbs.service';
import { IContextViewService } from 'vscode/vscode/vs/platform/contextview/browser/contextView.service';
import { ContextViewService } from 'vscode/vscode/vs/platform/contextview/browser/contextViewService';
import { ICodeEditorService } from 'vscode/vscode/vs/editor/browser/services/codeEditorService';
import { TextEditorService } from 'vscode/vscode/vs/workbench/services/textfile/common/textEditorService';
import { ITextEditorService } from 'vscode/vscode/vs/workbench/services/textfile/common/textEditorService.service';
import { CodeEditorService } from 'vscode/vscode/vs/workbench/services/editor/browser/codeEditorService';
import { UntitledTextEditorService } from './vscode/src/vs/workbench/services/untitled/common/untitledTextEditorService.js';
import { IUntitledTextEditorService } from 'vscode/vscode/vs/workbench/services/untitled/common/untitledTextEditorService.service';
import { IHistoryService } from 'vscode/vscode/vs/workbench/services/history/common/history.service';
import { HistoryService } from './vscode/src/vs/workbench/services/history/browser/historyService.js';
import { ICustomEditorService } from 'vscode/vscode/vs/workbench/contrib/customEditor/common/customEditor.service';
import { CustomEditorService } from './vscode/src/vs/workbench/contrib/customEditor/browser/customEditors.js';
import { WebviewService } from './vscode/src/vs/workbench/contrib/webview/browser/webviewService.js';
import { WebviewEditorService } from 'vscode/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService';
import { IWebviewWorkbenchService } from 'vscode/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService.service';
import { IWebviewService } from 'vscode/vscode/vs/workbench/contrib/webview/browser/webview.service';
import { WebviewViewService } from './vscode/src/vs/workbench/contrib/webviewView/browser/webviewViewService.js';
import { IWebviewViewService } from 'vscode/vscode/vs/workbench/contrib/webviewView/browser/webviewViewService.service';
import { IProgressService } from 'vscode/vscode/vs/platform/progress/common/progress.service';
import { ProgressService } from './vscode/src/vs/workbench/services/progress/browser/progressService.js';
import { PaneCompositePartService } from './vscode/src/vs/workbench/browser/parts/paneCompositePartService.js';
import { BrowserAuxiliaryWindowService } from './vscode/src/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService.js';
import { IAuxiliaryWindowService } from 'vscode/vscode/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService.service';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';
import { ViewsService } from 'vscode/vscode/vs/workbench/services/views/browser/viewsService';
import { IEditorPaneService } from 'vscode/vscode/vs/workbench/services/editor/common/editorPaneService.service';
import { EditorPaneService } from './vscode/src/vs/workbench/services/editor/browser/editorPaneService.js';
import { CustomEditorLabelService } from 'vscode/vscode/vs/workbench/services/editor/common/customEditorLabelService';
import { ICustomEditorLabelService } from 'vscode/vscode/vs/workbench/services/editor/common/customEditorLabelService.service';
import getServiceOverride$1 from '@codingame/monaco-vscode-bulk-edit-service-override';
import { changeUrlDomain } from './tools/url.js';
import { registerAssets } from 'vscode/assets';
import './vscode/src/vs/workbench/contrib/callHierarchy/browser/callHierarchy.contribution.js';
import './vscode/src/vs/workbench/contrib/typeHierarchy/browser/typeHierarchy.contribution.js';
import './vscode/src/vs/workbench/browser/actions/listCommands.js';
import 'vscode/vscode/vs/workbench/browser/parts/views/media/views.css';
import './vscode/src/vs/workbench/api/browser/viewsExtensionPoint.js';
import './vscode/src/vs/workbench/browser/parts/editor/editor.contribution.js';
import 'vscode/vscode/vs/workbench/browser/workbench.contribution';
import './vscode/src/vs/workbench/contrib/customEditor/browser/customEditor.contribution.js';
import './vscode/src/vs/workbench/contrib/webviewPanel/browser/webviewPanel.contribution.js';
import './vscode/src/vs/workbench/contrib/externalUriOpener/common/externalUriOpener.contribution.js';
import './vscode/src/vs/workbench/contrib/languageStatus/browser/languageStatus.contribution.js';
import './vscode/src/vs/workbench/contrib/mergeEditor/browser/mergeEditor.contribution.js';
import 'vscode/vscode/vs/workbench/contrib/webview/browser/webview.contribution';
import './vscode/src/vs/workbench/contrib/limitIndicator/browser/limitIndicator.contribution.js';
import './vscode/src/vs/workbench/contrib/sash/browser/sash.contribution.js';
import './vscode/src/vs/workbench/contrib/preferences/browser/keyboardLayoutPicker.js';
import 'vscode/vscode/vs/workbench/browser/parts/editor/editor.contribution._autosave';
import 'vscode/vscode/vs/workbench/contrib/files/browser/files.contribution._editorPane';
import 'vscode/vscode/vs/workbench/contrib/files/browser/fileCommands._save';
import './vscode/src/vs/workbench/browser/actions/navigationActions.js';
import './vscode/src/vs/workbench/browser/style.js';
import './tools/editorAssets.js';
import './vscode/src/vs/workbench/browser/parts/editor/editorParts.js';

let webviewIframeAlternateDomains;
registerAssets({
    'vs/workbench/contrib/webview/browser/pre/service-worker.js': () => changeUrlDomain(new URL('./assets/service-worker.js', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index.html': () => changeUrlDomain(new URL('./assets/index.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index-no-csp.html': () => changeUrlDomain(new URL('./assets/index-no-csp.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/fake.html': () => changeUrlDomain(new URL('./assets/fake.html', import.meta.url).href, webviewIframeAlternateDomains)
});
function getServiceOverride(_webviewIframeAlternateDomains) {
    if (_webviewIframeAlternateDomains != null) {
        webviewIframeAlternateDomains = _webviewIframeAlternateDomains;
    }
    return {
        ...getServiceOverride$1(),
        [( IViewsService.toString())]: new SyncDescriptor(ViewsService, [], false),
        [( IViewDescriptorService.toString())]: new SyncDescriptor(ViewDescriptorService, [], true),
        [( IActivityService.toString())]: new SyncDescriptor(ActivityService, [], true),
        [( IPaneCompositePartService.toString())]: new SyncDescriptor(PaneCompositePartService, [], true),
        [( ICodeEditorService.toString())]: new SyncDescriptor(CodeEditorService, [], true),
        [( ITextEditorService.toString())]: new SyncDescriptor(TextEditorService, [], false),
        [( IEditorResolverService.toString())]: new SyncDescriptor(EditorResolverService, [], false),
        [( IBreadcrumbsService.toString())]: new SyncDescriptor(BreadcrumbsService, [], true),
        [( IContextViewService.toString())]: new SyncDescriptor(ContextViewService, [], true),
        [( IUntitledTextEditorService.toString())]: new SyncDescriptor(UntitledTextEditorService, [], true),
        [( IHistoryService.toString())]: new SyncDescriptor(HistoryService, [], false),
        [( ICustomEditorService.toString())]: new SyncDescriptor(CustomEditorService, [], true),
        [( IWebviewService.toString())]: new SyncDescriptor(WebviewService, [], true),
        [( IWebviewViewService.toString())]: new SyncDescriptor(WebviewViewService, [], true),
        [( IWebviewWorkbenchService.toString())]: new SyncDescriptor(WebviewEditorService, [], true),
        [( IProgressService.toString())]: new SyncDescriptor(ProgressService, [], true),
        [( IAuxiliaryWindowService.toString())]: new SyncDescriptor(BrowserAuxiliaryWindowService, [], true),
        [( IEditorPaneService.toString())]: new SyncDescriptor(EditorPaneService, [], true),
        [( ICustomEditorLabelService.toString())]: new SyncDescriptor(CustomEditorLabelService, [], true)
    };
}

export { getServiceOverride as default };
